@@ -133,7 +133,7 @@ require Exporter;
 use vars qw/$VERSION @ISA @EXPORT_OK $EOS $AP $P $PAP @ABBREVIATIONS/;
 use Carp qw/cluck/;
 
-$VERSION = '0.16';
+$VERSION = '0.17';
 @ISA = qw( Exporter );
 @EXPORT_OK = qw( get_sentences 
 		add_acronyms get_acronyms set_acronyms
@@ -241,8 +241,8 @@ sub remove_false_end_of_sentence {
 ##	$marked_segment=~s/(\s\w$PAP)$EOS/$1/sg; 
 ##	## don't do u.s.a.
 ##	$marked_segment=~s/(\.\w$PAP)$EOS/$1/sg; 
-	$marked_segment=~s/(\W\w$PAP)$EOS/$1/sg;
-	$marked_segment=~s/(\W\w$P)$EOS/$1/sg;         
+	$marked_segment=~s/([^\w]\w$PAP)$EOS/$1/sg;
+	$marked_segment=~s/([^\w]\w$P)$EOS/$1/sg;         
 
 	# don't split |John P. Stenbit| into |John P.| and |Stenbit|
 	$marked_segment=~s/([A-Z]\w+\s+\S$P\s*)$EOS(\s*[A-Z])/$1$2/sg; 
